# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AuditLogServiceEventSelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entity_type': 'str',
        'event_types': 'list[AuditLogServiceEventTypes]'
    }

    attribute_map = {
        'entity_type': 'entityType',
        'event_types': 'eventTypes'
    }

    def __init__(self, entity_type=None, event_types=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogServiceEventSelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._entity_type = None
        self._event_types = None
        self.discriminator = None

        self.entity_type = entity_type
        self.event_types = event_types

    @property
    def entity_type(self):
        """Gets the entity_type of this AuditLogServiceEventSelector.  # noqa: E501

        <div lang=\"ja\">AuditLogServiceEntityTypeオブジェクトは、操作履歴に出力するエンティティの種類を表します。</div> <div lang=\"en\">AuditLogServiceEntityType object describes the type of entities to be output on the data of operation history.</div> <dl class=term>   <dt class=\"term__item\">CAMPAIGN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンです。</span><span lang=\"en\">Campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（キャンペーン）。</span><span lang=\"en\">Negative keywords (for campaign).</span></dd>   <dt class=\"term__item\">CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンのターゲティング設定です。</span><span lang=\"en\">Targeting setting on campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループです。</span><span lang=\"en\">Ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_BID_MULTIPLIER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループ入札価格調整率です。</span><span lang=\"en\">Bid adjustment for ad group.</span></dd>   <dt class=\"term__item\">BIDDABLE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">入札キーワードです。</span><span lang=\"en\">Bidding keyword.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（広告グループ）。</span><span lang=\"en\">Negative keywords (for ad group).</span></dd>   <dt class=\"term__item\">AD</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告です。</span><span lang=\"en\">Ad.</span></dd>   <dt class=\"term__item\">FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">Feedフォルダーです。</span><span lang=\"en\">Feed folder.</span></dd>   <dt class=\"term__item\">FEED_ITEM</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです。</span><span lang=\"en\">Ad display options.</span></dd>   <dt class=\"term__item\">CAMPAIGN_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（キャンペーン）。</span><span lang=\"en\">Ad display options for campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（広告グループ）。</span><span lang=\"en\">Ad display options for ad group.</span></dd>   <dt class=\"term__item\">SS_IO</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントです。</span><span lang=\"en\">Account.</span></dd>   <dt class=\"term__item\">SS_CONVERSION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">コンバージョントラッカー（コンバージョン測定）です。</span><span lang=\"en\">Conversion tracker for conversion tracking.</span></dd>   <dt class=\"term__item\">BIDDING_STRATEGY</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札設定です。</span><span lang=\"en\">Auto bidding setting.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（キャンペーン）。</span><span lang=\"en\">Exclude target list for campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（広告グループ）。</span><span lang=\"en\">Exclude target list for ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ターゲットリストです（広告グループ）。</span><span lang=\"en\">Target list for ad group.</span></dd>   <dt class=\"term__item\">TARGET_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">サイトリターゲテイングのターゲットリストです。</span><span lang=\"en\">Target list of Site Retargeting.</span></dd>   <dt class=\"term__item\">SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有リストです。</span><span lang=\"en\">Shared list.</span></dd>   <dt class=\"term__item\">SHARED_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有キーワードです。</span><span lang=\"en\">Shared keywords.</span></dd>   <dt class=\"term__item\">CAMPAIGN_SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン共有リストです。</span><span lang=\"en\">Shared list for campaign.</span></dd>   <dt class=\"term__item\">AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーです。</span><span lang=\"en\">Ad customizer.</span></dd>   <dt class=\"term__item\">EXCLUDE_AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーを除くすべての履歴です。</span><span lang=\"en\">All operation history excepting ad customizer.</span></dd>   <dt class=\"term__item\">ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アセット（広告表示オプション）です。</span><span lang=\"en\">Assets (Ad display option).</span></dd>   <dt class=\"term__item\">CAMPAIGN_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and assets.</span></dd>   <dt class=\"term__item\">AD_GROUP_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and assets.</span></dd>   <dt class=\"term__item\">ACCOUNT_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between account and customizer attributes.</span></dd>   <dt class=\"term__item\">CAMPAIGN_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CRITERION_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キーワードとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between keyword and customizer attributes.</span></dd>   <dt class=\"term__item\">CUSTOMIZER_ATTRIBUTE</dt>   <dd class=\"term__desc\"><span lang=\"ja\">カスタマイザー属性です。</span><span lang=\"en\">Customizer attributes.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットセットです。</span><span lang=\"en\">PageFeedAssetSet.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットです。</span><span lang=\"en\">PageFeedAsset.</span></dd>   <dt class=\"term__item\">BIDDING_SEASONALITY_ADJUSTMENT</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札のスポット調整です。</span><span lang=\"en\">Bidding Seasonality Adjustment.</span></dd>   <dt class=\"term__item\">CAMPAIGN_BUDGET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン間の共有予算です。<br>※現在、こちらのEnumは利用できません。</span><span lang=\"en\">Shared budgets.<br>*Currently this Enum is not available.</span></dd>   <dt class=\"term__item\">ALL</dt>   <dd class=\"term__desc\"><span lang=\"ja\">すべての履歴です。</span><span lang=\"en\">All operation history.</span></dd>   <dt class=\"term__item\">UNKNOWN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">未知の値です。</span><span lang=\"en\">Unknown value.</span></dd> </dl>   # noqa: E501

        :return: The entity_type of this AuditLogServiceEventSelector.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this AuditLogServiceEventSelector.

        <div lang=\"ja\">AuditLogServiceEntityTypeオブジェクトは、操作履歴に出力するエンティティの種類を表します。</div> <div lang=\"en\">AuditLogServiceEntityType object describes the type of entities to be output on the data of operation history.</div> <dl class=term>   <dt class=\"term__item\">CAMPAIGN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンです。</span><span lang=\"en\">Campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（キャンペーン）。</span><span lang=\"en\">Negative keywords (for campaign).</span></dd>   <dt class=\"term__item\">CAMPAIGN_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンのターゲティング設定です。</span><span lang=\"en\">Targeting setting on campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループです。</span><span lang=\"en\">Ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_BID_MULTIPLIER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループ入札価格調整率です。</span><span lang=\"en\">Bid adjustment for ad group.</span></dd>   <dt class=\"term__item\">BIDDABLE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">入札キーワードです。</span><span lang=\"en\">Bidding keyword.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外キーワードです（広告グループ）。</span><span lang=\"en\">Negative keywords (for ad group).</span></dd>   <dt class=\"term__item\">AD</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告です。</span><span lang=\"en\">Ad.</span></dd>   <dt class=\"term__item\">FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">Feedフォルダーです。</span><span lang=\"en\">Feed folder.</span></dd>   <dt class=\"term__item\">FEED_ITEM</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです。</span><span lang=\"en\">Ad display options.</span></dd>   <dt class=\"term__item\">CAMPAIGN_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（キャンペーン）。</span><span lang=\"en\">Ad display options for campaign.</span></dd>   <dt class=\"term__item\">AD_GROUP_FEED</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告表示オプションです（広告グループ）。</span><span lang=\"en\">Ad display options for ad group.</span></dd>   <dt class=\"term__item\">SS_IO</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントです。</span><span lang=\"en\">Account.</span></dd>   <dt class=\"term__item\">SS_CONVERSION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">コンバージョントラッカー（コンバージョン測定）です。</span><span lang=\"en\">Conversion tracker for conversion tracking.</span></dd>   <dt class=\"term__item\">BIDDING_STRATEGY</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札設定です。</span><span lang=\"en\">Auto bidding setting.</span></dd>   <dt class=\"term__item\">NEGATIVE_CAMPAIGN_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（キャンペーン）。</span><span lang=\"en\">Exclude target list for campaign.</span></dd>   <dt class=\"term__item\">NEGATIVE_AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">対象外ターゲットリストです（広告グループ）。</span><span lang=\"en\">Exclude target list for ad group.</span></dd>   <dt class=\"term__item\">AD_GROUP_USER_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ターゲットリストです（広告グループ）。</span><span lang=\"en\">Target list for ad group.</span></dd>   <dt class=\"term__item\">TARGET_LIST</dt>   <dd class=\"term__desc\"><span lang=\"ja\">サイトリターゲテイングのターゲットリストです。</span><span lang=\"en\">Target list of Site Retargeting.</span></dd>   <dt class=\"term__item\">SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有リストです。</span><span lang=\"en\">Shared list.</span></dd>   <dt class=\"term__item\">SHARED_CRITERION</dt>   <dd class=\"term__desc\"><span lang=\"ja\">共有キーワードです。</span><span lang=\"en\">Shared keywords.</span></dd>   <dt class=\"term__item\">CAMPAIGN_SHARED_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン共有リストです。</span><span lang=\"en\">Shared list for campaign.</span></dd>   <dt class=\"term__item\">AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーです。</span><span lang=\"en\">Ad customizer.</span></dd>   <dt class=\"term__item\">EXCLUDE_AD_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アドカスタマイザーを除くすべての履歴です。</span><span lang=\"en\">All operation history excepting ad customizer.</span></dd>   <dt class=\"term__item\">ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アセット（広告表示オプション）です。</span><span lang=\"en\">Assets (Ad display option).</span></dd>   <dt class=\"term__item\">CAMPAIGN_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and assets.</span></dd>   <dt class=\"term__item\">AD_GROUP_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとアセット間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and assets.</span></dd>   <dt class=\"term__item\">ACCOUNT_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">アカウントとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between account and customizer attributes.</span></dd>   <dt class=\"term__item\">CAMPAIGN_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーンとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between campaign and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">広告グループとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between ad group and customizer attributes.</span></dd>   <dt class=\"term__item\">AD_GROUP_CRITERION_CUSTOMIZER</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キーワードとカスタマイザー属性間の設定情報です。</span><span lang=\"en\">Configuration information between keyword and customizer attributes.</span></dd>   <dt class=\"term__item\">CUSTOMIZER_ATTRIBUTE</dt>   <dd class=\"term__desc\"><span lang=\"ja\">カスタマイザー属性です。</span><span lang=\"en\">Customizer attributes.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET_SET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットセットです。</span><span lang=\"en\">PageFeedAssetSet.</span></dd>   <dt class=\"term__item\">PAGE_FEED_ASSET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">ページフィードアセットです。</span><span lang=\"en\">PageFeedAsset.</span></dd>   <dt class=\"term__item\">BIDDING_SEASONALITY_ADJUSTMENT</dt>   <dd class=\"term__desc\"><span lang=\"ja\">自動入札のスポット調整です。</span><span lang=\"en\">Bidding Seasonality Adjustment.</span></dd>   <dt class=\"term__item\">CAMPAIGN_BUDGET</dt>   <dd class=\"term__desc\"><span lang=\"ja\">キャンペーン間の共有予算です。<br>※現在、こちらのEnumは利用できません。</span><span lang=\"en\">Shared budgets.<br>*Currently this Enum is not available.</span></dd>   <dt class=\"term__item\">ALL</dt>   <dd class=\"term__desc\"><span lang=\"ja\">すべての履歴です。</span><span lang=\"en\">All operation history.</span></dd>   <dt class=\"term__item\">UNKNOWN</dt>   <dd class=\"term__desc\"><span lang=\"ja\">未知の値です。</span><span lang=\"en\">Unknown value.</span></dd> </dl>   # noqa: E501

        :param entity_type: The entity_type of this AuditLogServiceEventSelector.  # noqa: E501
        :type: str
        """

        self._entity_type = entity_type

    @property
    def event_types(self):
        """Gets the event_types of this AuditLogServiceEventSelector.  # noqa: E501


        :return: The event_types of this AuditLogServiceEventSelector.  # noqa: E501
        :rtype: list[AuditLogServiceEventTypes]
        """
        return self._event_types

    @event_types.setter
    def event_types(self, event_types):
        """Sets the event_types of this AuditLogServiceEventSelector.


        :param event_types: The event_types of this AuditLogServiceEventSelector.  # noqa: E501
        :type: list[AuditLogServiceEventTypes]
        """

        self._event_types = event_types

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogServiceEventSelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogServiceEventSelector):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AssetServiceQuickLinkAsset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'link_text': 'str',
        'review_link_text': 'str',
        'description1': 'str',
        'review_description1': 'str',
        'description2': 'str',
        'review_description2': 'str',
        'start_date': 'str',
        'end_date': 'str',
        'schedules': 'list[AssetServiceSchedule]'
    }

    attribute_map = {
        'link_text': 'linkText',
        'review_link_text': 'reviewLinkText',
        'description1': 'description1',
        'review_description1': 'reviewDescription1',
        'description2': 'description2',
        'review_description2': 'reviewDescription2',
        'start_date': 'startDate',
        'end_date': 'endDate',
        'schedules': 'schedules'
    }

    def __init__(self, link_text=None, review_link_text=None, description1=None, review_description1=None, description2=None, review_description2=None, start_date=None, end_date=None, schedules=None, local_vars_configuration=None):  # noqa: E501
        """AssetServiceQuickLinkAsset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._link_text = None
        self._review_link_text = None
        self._description1 = None
        self._review_description1 = None
        self._description2 = None
        self._review_description2 = None
        self._start_date = None
        self._end_date = None
        self._schedules = None
        self.discriminator = None

        self.link_text = link_text
        self.review_link_text = review_link_text
        self.description1 = description1
        self.review_description1 = review_description1
        self.description2 = description2
        self.review_description2 = review_description2
        self.start_date = start_date
        self.end_date = end_date
        self.schedules = schedules

    @property
    def link_text(self):
        """Gets the link_text of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">リンクテキストです。<br> ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Link text.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :return: The link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._link_text

    @link_text.setter
    def link_text(self, link_text):
        """Sets the link_text of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">リンクテキストです。<br> ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Link text.<br> This field is required in ADD and SET operation.</div>   # noqa: E501

        :param link_text: The link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._link_text = link_text

    @property
    def review_link_text(self):
        """Gets the review_link_text of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">審査中のリンクテキストです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Link text on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._review_link_text

    @review_link_text.setter
    def review_link_text(self, review_link_text):
        """Sets the review_link_text of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">審査中のリンクテキストです。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Link text on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_link_text: The review_link_text of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._review_link_text = review_link_text

    @property
    def description1(self):
        """Gets the description1 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">説明文1です。</div> <div lang=\"en\">Description 1.</div>   # noqa: E501

        :return: The description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._description1

    @description1.setter
    def description1(self, description1):
        """Sets the description1 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">説明文1です。</div> <div lang=\"en\">Description 1.</div>   # noqa: E501

        :param description1: The description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._description1 = description1

    @property
    def review_description1(self):
        """Gets the review_description1 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">審査中の説明文1です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 1 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._review_description1

    @review_description1.setter
    def review_description1(self, review_description1):
        """Sets the review_description1 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">審査中の説明文1です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 1 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_description1: The review_description1 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._review_description1 = review_description1

    @property
    def description2(self):
        """Gets the description2 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">説明文2です。</div> <div lang=\"en\">Description 2.</div>   # noqa: E501

        :return: The description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._description2

    @description2.setter
    def description2(self, description2):
        """Sets the description2 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">説明文2です。</div> <div lang=\"en\">Description 2.</div>   # noqa: E501

        :param description2: The description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._description2 = description2

    @property
    def review_description2(self):
        """Gets the review_description2 of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">審査中の説明文2です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 2 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :return: The review_description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._review_description2

    @review_description2.setter
    def review_description2(self, review_description2):
        """Sets the review_description2 of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">審査中の説明文2です。<br> このフィールドは、リクエストの際には無視されます。<br> 審査中の間のみ、レスポンスの際に返却されます。</div> <div lang=\"en\">Description 2 on editorial review.<br> This field will be ignored on input.<br> It will be returned at the time of response only during the review.</div>   # noqa: E501

        :param review_description2: The review_description2 of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._review_description2 = review_description2

    @property
    def start_date(self):
        """Gets the start_date of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">配信開始日です。<br> ※空で設定すると、既存の配信開始日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">Start date of ad display<br> *On setting blank, existing start date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :return: The start_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">配信開始日です。<br> ※空で設定すると、既存の配信開始日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">Start date of ad display<br> *On setting blank, existing start date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :param start_date: The start_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this AssetServiceQuickLinkAsset.  # noqa: E501

        <div lang=\"ja\">配信終了日です。<br> ※空で設定すると、既存の配信終了日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">End date of ad display.<br> *By setting blank, existing end date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :return: The end_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this AssetServiceQuickLinkAsset.

        <div lang=\"ja\">配信終了日です。<br> ※空で設定すると、既存の配信終了日は削除されます。<br> このフィールドは、ADDおよびSET時に省略可能となり、REMOVE時に無視されます。</div> <div lang=\"en\">End date of ad display.<br> *By setting blank, existing end date of ad display will be deleted.<br> This field is optional in ADD and SET operation, and will be ignored in REMOVE operation.</div>   # noqa: E501

        :param end_date: The end_date of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def schedules(self):
        """Gets the schedules of this AssetServiceQuickLinkAsset.  # noqa: E501


        :return: The schedules of this AssetServiceQuickLinkAsset.  # noqa: E501
        :rtype: list[AssetServiceSchedule]
        """
        return self._schedules

    @schedules.setter
    def schedules(self, schedules):
        """Sets the schedules of this AssetServiceQuickLinkAsset.


        :param schedules: The schedules of this AssetServiceQuickLinkAsset.  # noqa: E501
        :type: list[AssetServiceSchedule]
        """

        self._schedules = schedules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetServiceQuickLinkAsset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetServiceQuickLinkAsset):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class CampaignExportServiceJob(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'end_date': 'str',
        'export_fields': 'list[str]',
        'job_id': 'int',
        'job_name': 'str',
        'job_status': 'CampaignExportServiceJobStatus',
        'progress': 'int',
        'start_date': 'str',
        'user_name': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'end_date': 'endDate',
        'export_fields': 'exportFields',
        'job_id': 'jobId',
        'job_name': 'jobName',
        'job_status': 'jobStatus',
        'progress': 'progress',
        'start_date': 'startDate',
        'user_name': 'userName'
    }

    def __init__(self, account_id=None, end_date=None, export_fields=None, job_id=None, job_name=None, job_status=None, progress=None, start_date=None, user_name=None, local_vars_configuration=None):  # noqa: E501
        """CampaignExportServiceJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._end_date = None
        self._export_fields = None
        self._job_id = None
        self._job_name = None
        self._job_status = None
        self._progress = None
        self._start_date = None
        self._user_name = None
        self.discriminator = None

        self.account_id = account_id
        self.end_date = end_date
        self.export_fields = export_fields
        self.job_id = job_id
        self.job_name = job_name
        self.job_status = job_status
        self.progress = progress
        self.start_date = start_date
        self.user_name = user_name

    @property
    def account_id(self):
        """Gets the account_id of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this CampaignExportServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this CampaignExportServiceJob.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this CampaignExportServiceJob.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def end_date(self):
        """Gets the end_date of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブの終了日時です。</div> <div lang=\"en\">End date and time of job setting.</div>   # noqa: E501

        :return: The end_date of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブの終了日時です。</div> <div lang=\"en\">End date and time of job setting.</div>   # noqa: E501

        :param end_date: The end_date of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def export_fields(self):
        """Gets the export_fields of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">エクスポートするフィールドです。</div> <div lang=\"en\">Fields to be exported.</div>   # noqa: E501

        :return: The export_fields of this CampaignExportServiceJob.  # noqa: E501
        :rtype: list[str]
        """
        return self._export_fields

    @export_fields.setter
    def export_fields(self, export_fields):
        """Sets the export_fields of this CampaignExportServiceJob.

        <div lang=\"ja\">エクスポートするフィールドです。</div> <div lang=\"en\">Fields to be exported.</div>   # noqa: E501

        :param export_fields: The export_fields of this CampaignExportServiceJob.  # noqa: E501
        :type: list[str]
        """

        self._export_fields = export_fields

    @property
    def job_id(self):
        """Gets the job_id of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブIDです。</div> <div lang=\"en\">CampaignExportServiceJob ID.</div>   # noqa: E501

        :return: The job_id of this CampaignExportServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブIDです。</div> <div lang=\"en\">CampaignExportServiceJob ID.</div>   # noqa: E501

        :param job_id: The job_id of this CampaignExportServiceJob.  # noqa: E501
        :type: int
        """

        self._job_id = job_id

    @property
    def job_name(self):
        """Gets the job_name of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブ名です。</div> <div lang=\"en\">CampaignExportServiceJob name.<br> ∗ Default: NULL</div>   # noqa: E501

        :return: The job_name of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブ名です。</div> <div lang=\"en\">CampaignExportServiceJob name.<br> ∗ Default: NULL</div>   # noqa: E501

        :param job_name: The job_name of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def job_status(self):
        """Gets the job_status of this CampaignExportServiceJob.  # noqa: E501


        :return: The job_status of this CampaignExportServiceJob.  # noqa: E501
        :rtype: CampaignExportServiceJobStatus
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this CampaignExportServiceJob.


        :param job_status: The job_status of this CampaignExportServiceJob.  # noqa: E501
        :type: CampaignExportServiceJobStatus
        """

        self._job_status = job_status

    @property
    def progress(self):
        """Gets the progress of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">処理進捗です。</div> <div lang=\"en\">Progress of job setting.</div>   # noqa: E501

        :return: The progress of this CampaignExportServiceJob.  # noqa: E501
        :rtype: int
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this CampaignExportServiceJob.

        <div lang=\"ja\">処理進捗です。</div> <div lang=\"en\">Progress of job setting.</div>   # noqa: E501

        :param progress: The progress of this CampaignExportServiceJob.  # noqa: E501
        :type: int
        """

        self._progress = progress

    @property
    def start_date(self):
        """Gets the start_date of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブの開始日時です。</div> <div lang=\"en\">Start date and time of job setting.</div>   # noqa: E501

        :return: The start_date of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブの開始日時です。</div> <div lang=\"en\">Start date and time of job setting.</div>   # noqa: E501

        :param start_date: The start_date of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def user_name(self):
        """Gets the user_name of this CampaignExportServiceJob.  # noqa: E501

        <div lang=\"ja\">ジョブ実行者のユーザー名です。</div> <div lang=\"en\">Name of user who run the job.</div>   # noqa: E501

        :return: The user_name of this CampaignExportServiceJob.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this CampaignExportServiceJob.

        <div lang=\"ja\">ジョブ実行者のユーザー名です。</div> <div lang=\"en\">Name of user who run the job.</div>   # noqa: E501

        :param user_name: The user_name of this CampaignExportServiceJob.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignExportServiceJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignExportServiceJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "yahoo-search-api-v11"
VERSION = "1.0.4"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    &lt;div lang&#x3D;\&quot;ja\&quot;&gt;Yahoo!広告 検索広告 APIのWebサービスについて説明します。&lt;/div&gt; &lt;div lang&#x3D;\&quot;en\&quot;&gt;Search Ads API Web Services supported in Yahoo! JAPAN Ads API.&lt;/div&gt; &lt;div&gt;&lt;a target&#x3D;\&quot;_blank\&quot; href&#x3D;\&quot;https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\&quot;&gt;OpenAPI Specification&lt;/a&gt;&lt;/div&gt; &lt;div lang&#x3D;\&quot;ja\&quot;&gt;&lt;a target&#x3D;\&quot;_blank\&quot; href&#x3D;\&quot;https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\&quot;&gt;Best Practice&lt;/a&gt;&lt;/div&gt; &lt;div lang&#x3D;\&quot;en\&quot;&gt;&lt;a target&#x3D;\&quot;_blank\&quot; href&#x3D;\&quot;https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\&quot;&gt;Best Practice&lt;/a&gt;&lt;/div&gt;   # noqa: E501
    """
)



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroup(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'bidding_strategy_configuration': 'AdGroupServiceBiddingStrategyConfiguration',
        'frequently_run_better_performing_ads_mode': 'AdGroupServiceFrequentlyRunBetterPerformingAdsMode',
        'ad_group_id': 'int',
        'ad_group_name': 'str',
        'ad_group_track_id': 'int',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'campaign_track_id': 'int',
        'custom_parameters': 'AdGroupServiceCustomParameters',
        'labels': 'list[AdGroupServiceLabel]',
        'settings': 'AdGroupServiceSettings',
        'tracking_url': 'str',
        'is_remove_tracking_url': 'AdGroupServiceIsRemoveFlg',
        'url_review_data': 'AdGroupServiceUrlReviewData',
        'user_status': 'AdGroupServiceUserStatus',
        'created_date': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'bidding_strategy_configuration': 'biddingStrategyConfiguration',
        'frequently_run_better_performing_ads_mode': 'frequentlyRunBetterPerformingAdsMode',
        'ad_group_id': 'adGroupId',
        'ad_group_name': 'adGroupName',
        'ad_group_track_id': 'adGroupTrackId',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'campaign_track_id': 'campaignTrackId',
        'custom_parameters': 'customParameters',
        'labels': 'labels',
        'settings': 'settings',
        'tracking_url': 'trackingUrl',
        'is_remove_tracking_url': 'isRemoveTrackingUrl',
        'url_review_data': 'urlReviewData',
        'user_status': 'userStatus',
        'created_date': 'createdDate'
    }

    def __init__(self, account_id=None, bidding_strategy_configuration=None, frequently_run_better_performing_ads_mode=None, ad_group_id=None, ad_group_name=None, ad_group_track_id=None, campaign_id=None, campaign_name=None, campaign_track_id=None, custom_parameters=None, labels=None, settings=None, tracking_url=None, is_remove_tracking_url=None, url_review_data=None, user_status=None, created_date=None, local_vars_configuration=None):  # noqa: E501
        """AdGroup - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._bidding_strategy_configuration = None
        self._frequently_run_better_performing_ads_mode = None
        self._ad_group_id = None
        self._ad_group_name = None
        self._ad_group_track_id = None
        self._campaign_id = None
        self._campaign_name = None
        self._campaign_track_id = None
        self._custom_parameters = None
        self._labels = None
        self._settings = None
        self._tracking_url = None
        self._is_remove_tracking_url = None
        self._url_review_data = None
        self._user_status = None
        self._created_date = None
        self.discriminator = None

        self.account_id = account_id
        self.bidding_strategy_configuration = bidding_strategy_configuration
        self.frequently_run_better_performing_ads_mode = frequently_run_better_performing_ads_mode
        self.ad_group_id = ad_group_id
        self.ad_group_name = ad_group_name
        self.ad_group_track_id = ad_group_track_id
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.campaign_track_id = campaign_track_id
        self.custom_parameters = custom_parameters
        self.labels = labels
        self.settings = settings
        self.tracking_url = tracking_url
        self.is_remove_tracking_url = is_remove_tracking_url
        self.url_review_data = url_review_data
        self.user_status = user_status
        self.created_date = created_date

    @property
    def account_id(self):
        """Gets the account_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The account_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this AdGroup.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param account_id: The account_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def bidding_strategy_configuration(self):
        """Gets the bidding_strategy_configuration of this AdGroup.  # noqa: E501


        :return: The bidding_strategy_configuration of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceBiddingStrategyConfiguration
        """
        return self._bidding_strategy_configuration

    @bidding_strategy_configuration.setter
    def bidding_strategy_configuration(self, bidding_strategy_configuration):
        """Sets the bidding_strategy_configuration of this AdGroup.


        :param bidding_strategy_configuration: The bidding_strategy_configuration of this AdGroup.  # noqa: E501
        :type: AdGroupServiceBiddingStrategyConfiguration
        """

        self._bidding_strategy_configuration = bidding_strategy_configuration

    @property
    def frequently_run_better_performing_ads_mode(self):
        """Gets the frequently_run_better_performing_ads_mode of this AdGroup.  # noqa: E501


        :return: The frequently_run_better_performing_ads_mode of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceFrequentlyRunBetterPerformingAdsMode
        """
        return self._frequently_run_better_performing_ads_mode

    @frequently_run_better_performing_ads_mode.setter
    def frequently_run_better_performing_ads_mode(self, frequently_run_better_performing_ads_mode):
        """Sets the frequently_run_better_performing_ads_mode of this AdGroup.


        :param frequently_run_better_performing_ads_mode: The frequently_run_better_performing_ads_mode of this AdGroup.  # noqa: E501
        :type: AdGroupServiceFrequentlyRunBetterPerformingAdsMode
        """

        self._frequently_run_better_performing_ads_mode = frequently_run_better_performing_ads_mode

    @property
    def ad_group_id(self):
        """Gets the ad_group_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">広告グループIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。</div> <div lang=\"en\">Ad group ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation.</div>   # noqa: E501

        :return: The ad_group_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_id

    @ad_group_id.setter
    def ad_group_id(self, ad_group_id):
        """Sets the ad_group_id of this AdGroup.

        <div lang=\"ja\">広告グループIDです。<br> このフィールドは、ADD時は無視され、SETおよびREMOVE時は必須となります。</div> <div lang=\"en\">Ad group ID.<br> This field will be ignored in ADD operation, and will be required in SET and REMOVE operation.</div>   # noqa: E501

        :param ad_group_id: The ad_group_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._ad_group_id = ad_group_id

    @property
    def ad_group_name(self):
        """Gets the ad_group_name of this AdGroup.  # noqa: E501

        <div lang=\"ja\">広告グループ名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Ad group name.<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The ad_group_name of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._ad_group_name

    @ad_group_name.setter
    def ad_group_name(self, ad_group_name):
        """Sets the ad_group_name of this AdGroup.

        <div lang=\"ja\">広告グループ名です。<br> このフィールドは、ADD時は必須となり、SET時は省略可能となります。</div> <div lang=\"en\">Ad group name.<br> This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param ad_group_name: The ad_group_name of this AdGroup.  # noqa: E501
        :type: str
        """

        self._ad_group_name = ad_group_name

    @property
    def ad_group_track_id(self):
        """Gets the ad_group_track_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">トラッキング用広告グループIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Ad group ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The ad_group_track_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._ad_group_track_id

    @ad_group_track_id.setter
    def ad_group_track_id(self, ad_group_track_id):
        """Sets the ad_group_track_id of this AdGroup.

        <div lang=\"ja\">トラッキング用広告グループIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Ad group ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param ad_group_track_id: The ad_group_track_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._ad_group_track_id = ad_group_track_id

    @property
    def campaign_id(self):
        """Gets the campaign_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">キャンペーンIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in any cases.</div>   # noqa: E501

        :return: The campaign_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this AdGroup.

        <div lang=\"ja\">キャンペーンIDです。<br> このフィールドは、いずれの場合でも必須となります。</div> <div lang=\"en\">Campaign ID.<br> This field is required in any cases.</div>   # noqa: E501

        :param campaign_id: The campaign_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this AdGroup.  # noqa: E501

        <div lang=\"ja\">キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign name.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The campaign_name of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this AdGroup.

        <div lang=\"ja\">キャンペーン名です。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign name.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param campaign_name: The campaign_name of this AdGroup.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def campaign_track_id(self):
        """Gets the campaign_track_id of this AdGroup.  # noqa: E501

        <div lang=\"ja\">トラッキング用キャンペーンIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The campaign_track_id of this AdGroup.  # noqa: E501
        :rtype: int
        """
        return self._campaign_track_id

    @campaign_track_id.setter
    def campaign_track_id(self, campaign_track_id):
        """Sets the campaign_track_id of this AdGroup.

        <div lang=\"ja\">トラッキング用キャンペーンIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param campaign_track_id: The campaign_track_id of this AdGroup.  # noqa: E501
        :type: int
        """

        self._campaign_track_id = campaign_track_id

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this AdGroup.  # noqa: E501


        :return: The custom_parameters of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this AdGroup.


        :param custom_parameters: The custom_parameters of this AdGroup.  # noqa: E501
        :type: AdGroupServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def labels(self):
        """Gets the labels of this AdGroup.  # noqa: E501


        :return: The labels of this AdGroup.  # noqa: E501
        :rtype: list[AdGroupServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this AdGroup.


        :param labels: The labels of this AdGroup.  # noqa: E501
        :type: list[AdGroupServiceLabel]
        """

        self._labels = labels

    @property
    def settings(self):
        """Gets the settings of this AdGroup.  # noqa: E501


        :return: The settings of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this AdGroup.


        :param settings: The settings of this AdGroup.  # noqa: E501
        :type: AdGroupServiceSettings
        """

        self._settings = settings

    @property
    def tracking_url(self):
        """Gets the tracking_url of this AdGroup.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> このフィールドは、省略可能となります。<br> ※キャンペーンがアプリキャンペーンでAndroidの場合、設定はできません。<br> ※SET時、こちらが審査中の場合、編集はできません。また、変更がない場合、審査対象とはなりません。</div> <div lang=\"en\">Tracking URL.<br> This field is optional.<br> *Cannot set for a Mobile App campaign for Android OS.<br> *In SET operation, cannot update it when this field is in editorial review. In addition, if there is no change, it will not to be reviewed.</div>   # noqa: E501

        :return: The tracking_url of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this AdGroup.

        <div lang=\"ja\">トラッキングURLです。<br> このフィールドは、省略可能となります。<br> ※キャンペーンがアプリキャンペーンでAndroidの場合、設定はできません。<br> ※SET時、こちらが審査中の場合、編集はできません。また、変更がない場合、審査対象とはなりません。</div> <div lang=\"en\">Tracking URL.<br> This field is optional.<br> *Cannot set for a Mobile App campaign for Android OS.<br> *In SET operation, cannot update it when this field is in editorial review. In addition, if there is no change, it will not to be reviewed.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this AdGroup.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def is_remove_tracking_url(self):
        """Gets the is_remove_tracking_url of this AdGroup.  # noqa: E501


        :return: The is_remove_tracking_url of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceIsRemoveFlg
        """
        return self._is_remove_tracking_url

    @is_remove_tracking_url.setter
    def is_remove_tracking_url(self, is_remove_tracking_url):
        """Sets the is_remove_tracking_url of this AdGroup.


        :param is_remove_tracking_url: The is_remove_tracking_url of this AdGroup.  # noqa: E501
        :type: AdGroupServiceIsRemoveFlg
        """

        self._is_remove_tracking_url = is_remove_tracking_url

    @property
    def url_review_data(self):
        """Gets the url_review_data of this AdGroup.  # noqa: E501


        :return: The url_review_data of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceUrlReviewData
        """
        return self._url_review_data

    @url_review_data.setter
    def url_review_data(self, url_review_data):
        """Sets the url_review_data of this AdGroup.


        :param url_review_data: The url_review_data of this AdGroup.  # noqa: E501
        :type: AdGroupServiceUrlReviewData
        """

        self._url_review_data = url_review_data

    @property
    def user_status(self):
        """Gets the user_status of this AdGroup.  # noqa: E501


        :return: The user_status of this AdGroup.  # noqa: E501
        :rtype: AdGroupServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this AdGroup.


        :param user_status: The user_status of this AdGroup.  # noqa: E501
        :type: AdGroupServiceUserStatus
        """

        self._user_status = user_status

    @property
    def created_date(self):
        """Gets the created_date of this AdGroup.  # noqa: E501

        <div lang=\"ja\">広告グループが作成された日です。<br>※フォーマット：yyyyMMdd</div> <div lang=\"en\">Date of ad group made.<br>* Format: yyyyMMdd</div>   # noqa: E501

        :return: The created_date of this AdGroup.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this AdGroup.

        <div lang=\"ja\">広告グループが作成された日です。<br>※フォーマット：yyyyMMdd</div> <div lang=\"en\">Date of ad group made.<br>* Format: yyyyMMdd</div>   # noqa: E501

        :param created_date: The created_date of this AdGroup.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroup):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroup):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from yahoo_search_api_v12.api_client import ApiClient
from yahoo_search_api_v12.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AdGroupAssetServiceApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def ad_group_asset_service_get_post(self, x_z_base_account_id, **kwargs):  # noqa: E501
        """ad_group_asset_service_get_post  # noqa: E501

        <div lang=\"ja\">広告グループとアセット間の設定情報を取得します。</div> <div lang=\"en\">Get configuration information between ad groups and assets.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ad_group_asset_service_get_post(x_z_base_account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int x_z_base_account_id: <div lang=\"ja\">アカウントIDを指定してください。</div> <div lang=\"en\">Specify Account ID.</div>  (required)
        :param AdGroupAssetServiceSelector ad_group_asset_service_selector:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdGroupAssetServiceGetResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.ad_group_asset_service_get_post_with_http_info(x_z_base_account_id, **kwargs)  # noqa: E501

    def ad_group_asset_service_get_post_with_http_info(self, x_z_base_account_id, **kwargs):  # noqa: E501
        """ad_group_asset_service_get_post  # noqa: E501

        <div lang=\"ja\">広告グループとアセット間の設定情報を取得します。</div> <div lang=\"en\">Get configuration information between ad groups and assets.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ad_group_asset_service_get_post_with_http_info(x_z_base_account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int x_z_base_account_id: <div lang=\"ja\">アカウントIDを指定してください。</div> <div lang=\"en\">Specify Account ID.</div>  (required)
        :param AdGroupAssetServiceSelector ad_group_asset_service_selector:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdGroupAssetServiceGetResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'x_z_base_account_id',
            'ad_group_asset_service_selector'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ad_group_asset_service_get_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'x_z_base_account_id' is set
        if self.api_client.client_side_validation and ('x_z_base_account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['x_z_base_account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `x_z_base_account_id` when calling `ad_group_asset_service_get_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_z_base_account_id' in local_var_params:
            header_params['x-z-base-account-id'] = local_var_params['x_z_base_account_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ad_group_asset_service_selector' in local_var_params:
            body_params = local_var_params['ad_group_asset_service_selector']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/AdGroupAssetService/get', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdGroupAssetServiceGetResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ad_group_asset_service_replace_post(self, x_z_base_account_id, **kwargs):  # noqa: E501
        """ad_group_asset_service_replace_post  # noqa: E501

        <div lang=\"ja\">広告グループにアセット情報を追加・更新・解除（削除）します。<br> ・更新は常に上書きされるため追加分を含めて更新する必要があります。<br> ・アセット情報を解除するときは空の情報で更新します。<br> ・1つの広告グループに設定できるステータスが有効なアセット情報は、各種それぞれ20件までです。<br> ・1つの広告グループに設定できるステータスが無効なアセット情報は、各種それぞれ2000件までです。</div> <div lang=\"en\">Add, update or release(remove) Asset information of ad group.<br> ・Update will overwrite the old information, so have to include the additional information on every updates.<br> ・To release FeedItem information, update with blank data.<br> ・Up to 20 asset information with valid status can be set for one ad group for each AdGroupAssetServiceType.<br> ・Up to 2000 asset information with invalid status can be set for one ad group for each AdGroupAssetServiceType.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ad_group_asset_service_replace_post(x_z_base_account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int x_z_base_account_id: <div lang=\"ja\">アカウントIDを指定してください。</div> <div lang=\"en\">Specify Account ID.</div>  (required)
        :param AdGroupAssetServiceReplaceOperation ad_group_asset_service_replace_operation:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdGroupAssetServiceReplaceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.ad_group_asset_service_replace_post_with_http_info(x_z_base_account_id, **kwargs)  # noqa: E501

    def ad_group_asset_service_replace_post_with_http_info(self, x_z_base_account_id, **kwargs):  # noqa: E501
        """ad_group_asset_service_replace_post  # noqa: E501

        <div lang=\"ja\">広告グループにアセット情報を追加・更新・解除（削除）します。<br> ・更新は常に上書きされるため追加分を含めて更新する必要があります。<br> ・アセット情報を解除するときは空の情報で更新します。<br> ・1つの広告グループに設定できるステータスが有効なアセット情報は、各種それぞれ20件までです。<br> ・1つの広告グループに設定できるステータスが無効なアセット情報は、各種それぞれ2000件までです。</div> <div lang=\"en\">Add, update or release(remove) Asset information of ad group.<br> ・Update will overwrite the old information, so have to include the additional information on every updates.<br> ・To release FeedItem information, update with blank data.<br> ・Up to 20 asset information with valid status can be set for one ad group for each AdGroupAssetServiceType.<br> ・Up to 2000 asset information with invalid status can be set for one ad group for each AdGroupAssetServiceType.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ad_group_asset_service_replace_post_with_http_info(x_z_base_account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int x_z_base_account_id: <div lang=\"ja\">アカウントIDを指定してください。</div> <div lang=\"en\">Specify Account ID.</div>  (required)
        :param AdGroupAssetServiceReplaceOperation ad_group_asset_service_replace_operation:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdGroupAssetServiceReplaceResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'x_z_base_account_id',
            'ad_group_asset_service_replace_operation'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ad_group_asset_service_replace_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'x_z_base_account_id' is set
        if self.api_client.client_side_validation and ('x_z_base_account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['x_z_base_account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `x_z_base_account_id` when calling `ad_group_asset_service_replace_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_z_base_account_id' in local_var_params:
            header_params['x-z-base-account-id'] = local_var_params['x_z_base_account_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ad_group_asset_service_replace_operation' in local_var_params:
            body_params = local_var_params['ad_group_asset_service_replace_operation']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/AdGroupAssetService/replace', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdGroupAssetServiceReplaceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def ad_group_asset_service_set_post(self, x_z_base_account_id, **kwargs):  # noqa: E501
        """ad_group_asset_service_set_post  # noqa: E501

        <div lang=\"ja\">広告グループとアセット間の設定情報を更新します。<br> ・1つの広告グループに設定できるステータスが有効なアセット情報は、各種それぞれ20件までです。<br> ・1つの広告グループに設定できるステータスが無効なアセット情報は、各種それぞれ2000件までです。</div> <div lang=\"en\">Updates configuration information between ad groups and assets.<br> ・Up to 20 asset information with valid status can be set for one ad group for each AdGroupAssetServiceType.<br> ・Up to 2000 asset information with invalid status can be set for one ad group for each AdGroupAssetServiceType.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ad_group_asset_service_set_post(x_z_base_account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int x_z_base_account_id: <div lang=\"ja\">アカウントIDを指定してください。</div> <div lang=\"en\">Specify Account ID.</div>  (required)
        :param AdGroupAssetServiceOperation ad_group_asset_service_operation:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: AdGroupAssetServiceMutateResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.ad_group_asset_service_set_post_with_http_info(x_z_base_account_id, **kwargs)  # noqa: E501

    def ad_group_asset_service_set_post_with_http_info(self, x_z_base_account_id, **kwargs):  # noqa: E501
        """ad_group_asset_service_set_post  # noqa: E501

        <div lang=\"ja\">広告グループとアセット間の設定情報を更新します。<br> ・1つの広告グループに設定できるステータスが有効なアセット情報は、各種それぞれ20件までです。<br> ・1つの広告グループに設定できるステータスが無効なアセット情報は、各種それぞれ2000件までです。</div> <div lang=\"en\">Updates configuration information between ad groups and assets.<br> ・Up to 20 asset information with valid status can be set for one ad group for each AdGroupAssetServiceType.<br> ・Up to 2000 asset information with invalid status can be set for one ad group for each AdGroupAssetServiceType.</div>   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.ad_group_asset_service_set_post_with_http_info(x_z_base_account_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int x_z_base_account_id: <div lang=\"ja\">アカウントIDを指定してください。</div> <div lang=\"en\">Specify Account ID.</div>  (required)
        :param AdGroupAssetServiceOperation ad_group_asset_service_operation:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(AdGroupAssetServiceMutateResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'x_z_base_account_id',
            'ad_group_asset_service_operation'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method ad_group_asset_service_set_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'x_z_base_account_id' is set
        if self.api_client.client_side_validation and ('x_z_base_account_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['x_z_base_account_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `x_z_base_account_id` when calling `ad_group_asset_service_set_post`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_z_base_account_id' in local_var_params:
            header_params['x-z-base-account-id'] = local_var_params['x_z_base_account_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ad_group_asset_service_operation' in local_var_params:
            body_params = local_var_params['ad_group_asset_service_operation']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oAuth']  # noqa: E501

        return self.api_client.call_api(
            '/AdGroupAssetService/set', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AdGroupAssetServiceMutateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class FeedItemServicePlaceholderField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    LINK_TEXT = "LINK_TEXT"
    LINK_DESCRIPTION_1 = "LINK_DESCRIPTION_1"
    LINK_DESCRIPTION_2 = "LINK_DESCRIPTION_2"
    ADVANCED_URL = "ADVANCED_URL"
    ADVANCED_MOBILE_URL = "ADVANCED_MOBILE_URL"
    TRACKING_URL = "TRACKING_URL"
    CALL_PHONE_NUMBER = "CALL_PHONE_NUMBER"
    AD_CUSTOMIZER_INTEGER = "AD_CUSTOMIZER_INTEGER"
    AD_CUSTOMIZER_PRICE = "AD_CUSTOMIZER_PRICE"
    AD_CUSTOMIZER_DATE = "AD_CUSTOMIZER_DATE"
    AD_CUSTOMIZER_STRING = "AD_CUSTOMIZER_STRING"
    CALLOUT_TEXT = "CALLOUT_TEXT"
    ADDITIONAL_ADVANCED_URLS = "ADDITIONAL_ADVANCED_URLS"
    ADDITIONAL_ADVANCED_MOBILE_URLS = "ADDITIONAL_ADVANCED_MOBILE_URLS"
    STRUCTURED_SNIPPET_HEADER = "STRUCTURED_SNIPPET_HEADER"
    STRUCTURED_SNIPPET_VALUES = "STRUCTURED_SNIPPET_VALUES"
    UNKNOWN = "UNKNOWN"

    allowable_values = [LINK_TEXT, LINK_DESCRIPTION_1, LINK_DESCRIPTION_2, ADVANCED_URL, ADVANCED_MOBILE_URL, TRACKING_URL, CALL_PHONE_NUMBER, AD_CUSTOMIZER_INTEGER, AD_CUSTOMIZER_PRICE, AD_CUSTOMIZER_DATE, AD_CUSTOMIZER_STRING, CALLOUT_TEXT, ADDITIONAL_ADVANCED_URLS, ADDITIONAL_ADVANCED_MOBILE_URLS, STRUCTURED_SNIPPET_HEADER, STRUCTURED_SNIPPET_VALUES, UNKNOWN]  # noqa: E501

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
    }

    attribute_map = {
    }

    def __init__(self, local_vars_configuration=None):  # noqa: E501
        """FeedItemServicePlaceholderField - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FeedItemServicePlaceholderField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FeedItemServicePlaceholderField):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceDescriptionTextAsset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'text': 'str',
        'pinned_field': 'AdGroupAdServiceDescriptionPinnedField',
        'active_status': 'AdGroupAdServiceTextAssetActiveStatus',
        'approval_status': 'AdGroupAdServiceApprovalStatus',
        'disapproval_reason_codes': 'list[str]'
    }

    attribute_map = {
        'text': 'text',
        'pinned_field': 'pinnedField',
        'active_status': 'activeStatus',
        'approval_status': 'approvalStatus',
        'disapproval_reason_codes': 'disapprovalReasonCodes'
    }

    def __init__(self, text=None, pinned_field=None, active_status=None, approval_status=None, disapproval_reason_codes=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceDescriptionTextAsset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._text = None
        self._pinned_field = None
        self._active_status = None
        self._approval_status = None
        self._disapproval_reason_codes = None
        self.discriminator = None

        self.text = text
        self.pinned_field = pinned_field
        self.active_status = active_status
        self.approval_status = approval_status
        self.disapproval_reason_codes = disapproval_reason_codes

    @property
    def text(self):
        """Gets the text of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501

        <div lang=\"ja\">テキストです。<br>ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Text of parameter.<br>This field is required in ADD and SET operation.</div>   # noqa: E501

        :return: The text of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this AdGroupAdServiceDescriptionTextAsset.

        <div lang=\"ja\">テキストです。<br>ADDおよびSET時、このフィールドは必須となります。</div> <div lang=\"en\">Text of parameter.<br>This field is required in ADD and SET operation.</div>   # noqa: E501

        :param text: The text of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def pinned_field(self):
        """Gets the pinned_field of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501


        :return: The pinned_field of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: AdGroupAdServiceDescriptionPinnedField
        """
        return self._pinned_field

    @pinned_field.setter
    def pinned_field(self, pinned_field):
        """Sets the pinned_field of this AdGroupAdServiceDescriptionTextAsset.


        :param pinned_field: The pinned_field of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: AdGroupAdServiceDescriptionPinnedField
        """

        self._pinned_field = pinned_field

    @property
    def active_status(self):
        """Gets the active_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501


        :return: The active_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: AdGroupAdServiceTextAssetActiveStatus
        """
        return self._active_status

    @active_status.setter
    def active_status(self, active_status):
        """Sets the active_status of this AdGroupAdServiceDescriptionTextAsset.


        :param active_status: The active_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: AdGroupAdServiceTextAssetActiveStatus
        """

        self._active_status = active_status

    @property
    def approval_status(self):
        """Gets the approval_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501


        :return: The approval_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: AdGroupAdServiceApprovalStatus
        """
        return self._approval_status

    @approval_status.setter
    def approval_status(self, approval_status):
        """Sets the approval_status of this AdGroupAdServiceDescriptionTextAsset.


        :param approval_status: The approval_status of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: AdGroupAdServiceApprovalStatus
        """

        self._approval_status = approval_status

    @property
    def disapproval_reason_codes(self):
        """Gets the disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501

        <div lang=\"ja\">審査否認の理由コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Code of Disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details) <br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :rtype: list[str]
        """
        return self._disapproval_reason_codes

    @disapproval_reason_codes.setter
    def disapproval_reason_codes(self, disapproval_reason_codes):
        """Sets the disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.

        <div lang=\"ja\">審査否認の理由コードです。<br> (コード詳細は、DictionaryServiceのgetDisapprovalReasonのレスポンスを参照)<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Code of Disapproval reason.<br> (Refer to DictionaryService getDisapprovalReason response for details) <br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param disapproval_reason_codes: The disapproval_reason_codes of this AdGroupAdServiceDescriptionTextAsset.  # noqa: E501
        :type: list[str]
        """

        self._disapproval_reason_codes = disapproval_reason_codes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceDescriptionTextAsset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceDescriptionTextAsset):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AccountManagementServiceClient(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'building': 'str',
        'city': 'str',
        'client_person_name': 'str',
        'company_name': 'str',
        'company_name_kana': 'str',
        'corporate_number': 'int',
        'enterprise_type': 'AccountManagementServiceEnterpriseType',
        'enterprise_type_position': 'AccountManagementServiceEnterpriseTypePosition',
        'phone_number': 'str',
        'prefecture_code': 'AccountManagementServicePrefectureCode',
        'street1': 'str',
        'street2': 'str',
        'url': 'str',
        'url_type': 'AccountManagementServiceUrlType',
        'zip': 'str'
    }

    attribute_map = {
        'building': 'building',
        'city': 'city',
        'client_person_name': 'clientPersonName',
        'company_name': 'companyName',
        'company_name_kana': 'companyNameKana',
        'corporate_number': 'corporateNumber',
        'enterprise_type': 'enterpriseType',
        'enterprise_type_position': 'enterpriseTypePosition',
        'phone_number': 'phoneNumber',
        'prefecture_code': 'prefectureCode',
        'street1': 'street1',
        'street2': 'street2',
        'url': 'url',
        'url_type': 'urlType',
        'zip': 'zip'
    }

    def __init__(self, building=None, city=None, client_person_name=None, company_name=None, company_name_kana=None, corporate_number=None, enterprise_type=None, enterprise_type_position=None, phone_number=None, prefecture_code=None, street1=None, street2=None, url=None, url_type=None, zip=None, local_vars_configuration=None):  # noqa: E501
        """AccountManagementServiceClient - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._building = None
        self._city = None
        self._client_person_name = None
        self._company_name = None
        self._company_name_kana = None
        self._corporate_number = None
        self._enterprise_type = None
        self._enterprise_type_position = None
        self._phone_number = None
        self._prefecture_code = None
        self._street1 = None
        self._street2 = None
        self._url = None
        self._url_type = None
        self._zip = None
        self.discriminator = None

        self.building = building
        self.city = city
        self.client_person_name = client_person_name
        self.company_name = company_name
        self.company_name_kana = company_name_kana
        self.corporate_number = corporate_number
        self.enterprise_type = enterprise_type
        self.enterprise_type_position = enterprise_type_position
        self.phone_number = phone_number
        self.prefecture_code = prefecture_code
        self.street1 = street1
        self.street2 = street2
        self.url = url
        self.url_type = url_type
        self.zip = zip

    @property
    def building(self):
        """Gets the building of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">ビル名です。<br>このフィールドは、ADD時に省略可能となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Building name.<br>This field is optional in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :return: The building of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._building

    @building.setter
    def building(self, building):
        """Sets the building of this AccountManagementServiceClient.

        <div lang=\"ja\">ビル名です。<br>このフィールドは、ADD時に省略可能となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Building name.<br>This field is optional in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :param building: The building of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._building = building

    @property
    def city(self):
        """Gets the city of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">市区町村名です。<br>このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">City name.<br>This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :return: The city of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this AccountManagementServiceClient.

        <div lang=\"ja\">市区町村名です。<br>このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">City name.<br>This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :param city: The city of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def client_person_name(self):
        """Gets the client_person_name of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">広告主の担当者氏名です。<br> このフィールドは、ADD時に省略可能となり、SET時に無視されます。</div> <div lang=\"en\">Client person name.<br> This field is optional in ADD operation, and will be ignored in SET operation.</div>   # noqa: E501

        :return: The client_person_name of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._client_person_name

    @client_person_name.setter
    def client_person_name(self, client_person_name):
        """Sets the client_person_name of this AccountManagementServiceClient.

        <div lang=\"ja\">広告主の担当者氏名です。<br> このフィールドは、ADD時に省略可能となり、SET時に無視されます。</div> <div lang=\"en\">Client person name.<br> This field is optional in ADD operation, and will be ignored in SET operation.</div>   # noqa: E501

        :param client_person_name: The client_person_name of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._client_person_name = client_person_name

    @property
    def company_name(self):
        """Gets the company_name of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">広告主名です。<br>このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。</div> <div lang=\"en\">Company name.<br>This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.</div>   # noqa: E501

        :return: The company_name of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this AccountManagementServiceClient.

        <div lang=\"ja\">広告主名です。<br>このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。</div> <div lang=\"en\">Company name.<br>This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.</div>   # noqa: E501

        :param company_name: The company_name of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def company_name_kana(self):
        """Gets the company_name_kana of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">広告主名カナです。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。</div> <div lang=\"en\">Kana characters of company name.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.</div>   # noqa: E501

        :return: The company_name_kana of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._company_name_kana

    @company_name_kana.setter
    def company_name_kana(self, company_name_kana):
        """Sets the company_name_kana of this AccountManagementServiceClient.

        <div lang=\"ja\">広告主名カナです。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。</div> <div lang=\"en\">Kana characters of company name.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.</div>   # noqa: E501

        :param company_name_kana: The company_name_kana of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._company_name_kana = company_name_kana

    @property
    def corporate_number(self):
        """Gets the corporate_number of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\"> 法人番号です。<br> このフィールドは、ADD時に省略可能となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※enterpriseTypeがKOJINの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。 </div> <div lang=\"en\"> Corporate number.<br> This field is optional in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * When enterpriseType is \"KOJIN\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response. </div>   # noqa: E501

        :return: The corporate_number of this AccountManagementServiceClient.  # noqa: E501
        :rtype: int
        """
        return self._corporate_number

    @corporate_number.setter
    def corporate_number(self, corporate_number):
        """Sets the corporate_number of this AccountManagementServiceClient.

        <div lang=\"ja\"> 法人番号です。<br> このフィールドは、ADD時に省略可能となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※enterpriseTypeがKOJINの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。 </div> <div lang=\"en\"> Corporate number.<br> This field is optional in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * When enterpriseType is \"KOJIN\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response. </div>   # noqa: E501

        :param corporate_number: The corporate_number of this AccountManagementServiceClient.  # noqa: E501
        :type: int
        """

        self._corporate_number = corporate_number

    @property
    def enterprise_type(self):
        """Gets the enterprise_type of this AccountManagementServiceClient.  # noqa: E501


        :return: The enterprise_type of this AccountManagementServiceClient.  # noqa: E501
        :rtype: AccountManagementServiceEnterpriseType
        """
        return self._enterprise_type

    @enterprise_type.setter
    def enterprise_type(self, enterprise_type):
        """Sets the enterprise_type of this AccountManagementServiceClient.


        :param enterprise_type: The enterprise_type of this AccountManagementServiceClient.  # noqa: E501
        :type: AccountManagementServiceEnterpriseType
        """

        self._enterprise_type = enterprise_type

    @property
    def enterprise_type_position(self):
        """Gets the enterprise_type_position of this AccountManagementServiceClient.  # noqa: E501


        :return: The enterprise_type_position of this AccountManagementServiceClient.  # noqa: E501
        :rtype: AccountManagementServiceEnterpriseTypePosition
        """
        return self._enterprise_type_position

    @enterprise_type_position.setter
    def enterprise_type_position(self, enterprise_type_position):
        """Sets the enterprise_type_position of this AccountManagementServiceClient.


        :param enterprise_type_position: The enterprise_type_position of this AccountManagementServiceClient.  # noqa: E501
        :type: AccountManagementServiceEnterpriseTypePosition
        """

        self._enterprise_type_position = enterprise_type_position

    @property
    def phone_number(self):
        """Gets the phone_number of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">電話番号です。<br> ※xxxxx-xxxxx-xxxxx形式です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Phone number.<br> * In xxxxx-xxxxx-xxxxx format.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :return: The phone_number of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this AccountManagementServiceClient.

        <div lang=\"ja\">電話番号です。<br> ※xxxxx-xxxxx-xxxxx形式です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Phone number.<br> * In xxxxx-xxxxx-xxxxx format.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :param phone_number: The phone_number of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                phone_number is not None and not re.search(r'^\d{1,5}-\d{1,5}-\d{1,5}$', phone_number)):  # noqa: E501
            raise ValueError(r"Invalid value for `phone_number`, must be a follow pattern or equal to `/^\d{1,5}-\d{1,5}-\d{1,5}$/`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def prefecture_code(self):
        """Gets the prefecture_code of this AccountManagementServiceClient.  # noqa: E501


        :return: The prefecture_code of this AccountManagementServiceClient.  # noqa: E501
        :rtype: AccountManagementServicePrefectureCode
        """
        return self._prefecture_code

    @prefecture_code.setter
    def prefecture_code(self, prefecture_code):
        """Sets the prefecture_code of this AccountManagementServiceClient.


        :param prefecture_code: The prefecture_code of this AccountManagementServiceClient.  # noqa: E501
        :type: AccountManagementServicePrefectureCode
        """

        self._prefecture_code = prefecture_code

    @property
    def street1(self):
        """Gets the street1 of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">町・字名です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Street1.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :return: The street1 of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._street1

    @street1.setter
    def street1(self, street1):
        """Sets the street1 of this AccountManagementServiceClient.

        <div lang=\"ja\">町・字名です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Street1.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :param street1: The street1 of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._street1 = street1

    @property
    def street2(self):
        """Gets the street2 of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">丁目・番地・号です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Street2.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :return: The street2 of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._street2

    @street2.setter
    def street2(self, street2):
        """Sets the street2 of this AccountManagementServiceClient.

        <div lang=\"ja\">丁目・番地・号です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Street2.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :param street2: The street2 of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._street2 = street2

    @property
    def url(self):
        """Gets the url of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">広告掲載を希望するサイトのURLです。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。</div> <div lang=\"en\">Site URL for placing advertisement.<br> This field is required in ADD operation, and will be ignored in SET operation.</div>   # noqa: E501

        :return: The url of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this AccountManagementServiceClient.

        <div lang=\"ja\">広告掲載を希望するサイトのURLです。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。</div> <div lang=\"en\">Site URL for placing advertisement.<br> This field is required in ADD operation, and will be ignored in SET operation.</div>   # noqa: E501

        :param url: The url of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def url_type(self):
        """Gets the url_type of this AccountManagementServiceClient.  # noqa: E501


        :return: The url_type of this AccountManagementServiceClient.  # noqa: E501
        :rtype: AccountManagementServiceUrlType
        """
        return self._url_type

    @url_type.setter
    def url_type(self, url_type):
        """Sets the url_type of this AccountManagementServiceClient.


        :param url_type: The url_type of this AccountManagementServiceClient.  # noqa: E501
        :type: AccountManagementServiceUrlType
        """

        self._url_type = url_type

    @property
    def zip(self):
        """Gets the zip of this AccountManagementServiceClient.  # noqa: E501

        <div lang=\"ja\">郵便番号です。<br> ※xxx-xxxx形式です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Zip code.<br> * In xxx-xxxx format.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :return: The zip of this AccountManagementServiceClient.  # noqa: E501
        :rtype: str
        """
        return self._zip

    @zip.setter
    def zip(self, zip):
        """Sets the zip of this AccountManagementServiceClient.

        <div lang=\"ja\">郵便番号です。<br> ※xxx-xxxx形式です。<br> このフィールドは、ADD時に必須となり、SET時に無視されます。<br> ※clientTypeがSELFの場合は、ADD時、SET時ともに無視されます。<br> ※このフィールドは、レスポンスの際に返却されません。</div> <div lang=\"en\">Zip code.<br> * In xxx-xxxx format.<br> This field is required in ADD operation, and will be ignored in SET operation.<br> * When clientType is \"SELF\", this field will be ignored in ADD and SET operations.<br> * This field is not returned in the response.</div>   # noqa: E501

        :param zip: The zip of this AccountManagementServiceClient.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                zip is not None and not re.search(r'^\d{3}-\d{4}$', zip)):  # noqa: E501
            raise ValueError(r"Invalid value for `zip`, must be a follow pattern or equal to `/^\d{3}-\d{4}$/`")  # noqa: E501

        self._zip = zip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountManagementServiceClient):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountManagementServiceClient):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class ConversionTrackerServiceAppEvent(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conversion_tracker_track_id': 'int',
        'app_vendor_id': 'str',
        'app_id': 'str',
        'app_link_platform': 'ConversionTrackerServiceAppLinkPlatform',
        'app_event_type': 'str'
    }

    attribute_map = {
        'conversion_tracker_track_id': 'conversionTrackerTrackId',
        'app_vendor_id': 'appVendorId',
        'app_id': 'appId',
        'app_link_platform': 'appLinkPlatform',
        'app_event_type': 'appEventType'
    }

    def __init__(self, conversion_tracker_track_id=None, app_vendor_id=None, app_id=None, app_link_platform=None, app_event_type=None, local_vars_configuration=None):  # noqa: E501
        """ConversionTrackerServiceAppEvent - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._conversion_tracker_track_id = None
        self._app_vendor_id = None
        self._app_id = None
        self._app_link_platform = None
        self._app_event_type = None
        self.discriminator = None

        self.conversion_tracker_track_id = conversion_tracker_track_id
        self.app_vendor_id = app_vendor_id
        self.app_id = app_id
        self.app_link_platform = app_link_platform
        self.app_event_type = app_event_type

    @property
    def conversion_tracker_track_id(self):
        """Gets the conversion_tracker_track_id of this ConversionTrackerServiceAppEvent.  # noqa: E501

        <div lang=\"ja\">トラッキング用コンバージョントラッカーIDです。</div> <div lang=\"en\">ConversionTracker ID for tracking.</div>   # noqa: E501

        :return: The conversion_tracker_track_id of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :rtype: int
        """
        return self._conversion_tracker_track_id

    @conversion_tracker_track_id.setter
    def conversion_tracker_track_id(self, conversion_tracker_track_id):
        """Sets the conversion_tracker_track_id of this ConversionTrackerServiceAppEvent.

        <div lang=\"ja\">トラッキング用コンバージョントラッカーIDです。</div> <div lang=\"en\">ConversionTracker ID for tracking.</div>   # noqa: E501

        :param conversion_tracker_track_id: The conversion_tracker_track_id of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :type: int
        """

        self._conversion_tracker_track_id = conversion_tracker_track_id

    @property
    def app_vendor_id(self):
        """Gets the app_vendor_id of this ConversionTrackerServiceAppEvent.  # noqa: E501

        <div lang=\"ja\">アプリ計測ベンダー識別子です。</div> <div lang=\"en\">Application vendor ID.</div>   # noqa: E501

        :return: The app_vendor_id of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :rtype: str
        """
        return self._app_vendor_id

    @app_vendor_id.setter
    def app_vendor_id(self, app_vendor_id):
        """Sets the app_vendor_id of this ConversionTrackerServiceAppEvent.

        <div lang=\"ja\">アプリ計測ベンダー識別子です。</div> <div lang=\"en\">Application vendor ID.</div>   # noqa: E501

        :param app_vendor_id: The app_vendor_id of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :type: str
        """

        self._app_vendor_id = app_vendor_id

    @property
    def app_id(self):
        """Gets the app_id of this ConversionTrackerServiceAppEvent.  # noqa: E501

        <div lang=\"ja\">アプリケーションIDです。</div> <div lang=\"en\">Application ID.</div>   # noqa: E501

        :return: The app_id of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this ConversionTrackerServiceAppEvent.

        <div lang=\"ja\">アプリケーションIDです。</div> <div lang=\"en\">Application ID.</div>   # noqa: E501

        :param app_id: The app_id of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def app_link_platform(self):
        """Gets the app_link_platform of this ConversionTrackerServiceAppEvent.  # noqa: E501


        :return: The app_link_platform of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :rtype: ConversionTrackerServiceAppLinkPlatform
        """
        return self._app_link_platform

    @app_link_platform.setter
    def app_link_platform(self, app_link_platform):
        """Sets the app_link_platform of this ConversionTrackerServiceAppEvent.


        :param app_link_platform: The app_link_platform of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :type: ConversionTrackerServiceAppLinkPlatform
        """

        self._app_link_platform = app_link_platform

    @property
    def app_event_type(self):
        """Gets the app_event_type of this ConversionTrackerServiceAppEvent.  # noqa: E501

        <div lang=\"ja\">アプリイベントタイプです。</div> <div lang=\"en\">Application event type.</div>   # noqa: E501

        :return: The app_event_type of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :rtype: str
        """
        return self._app_event_type

    @app_event_type.setter
    def app_event_type(self, app_event_type):
        """Sets the app_event_type of this ConversionTrackerServiceAppEvent.

        <div lang=\"ja\">アプリイベントタイプです。</div> <div lang=\"en\">Application event type.</div>   # noqa: E501

        :param app_event_type: The app_event_type of this ConversionTrackerServiceAppEvent.  # noqa: E501
        :type: str
        """

        self._app_event_type = app_event_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversionTrackerServiceAppEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConversionTrackerServiceAppEvent):
            return True

        return self.to_dict() != other.to_dict()
